@@ -1,7 +1,7 @@
 package TableData::Object;
 
-our $DATE = '2015-10-29'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-11-02'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -20,16 +20,20 @@ sub new {
     if (!defined($data)) {
         die "Please specify table data";
     } elsif (ref($data) eq 'HASH') {
+        require TableData::Object::hash;
         TableData::Object::hash->new($data);
-    } elsif (is_aos($data, {max=>10})) {
-        TableData::Object::aos->new($data);
     } elsif (is_aoaos($data, {max=>10})) {
+        require TableData::Object::aoaos;
         TableData::Object::aoaos->new($data, $spec);
-    }elsif (is_aohos($data, {max=>10})) {
+    } elsif (is_aohos($data, {max=>10})) {
+        require TableData::Object::aohos;
         TableData::Object::aohos->new($data, $spec);
+    } elsif (ref($data) eq 'ARRAY') {
+        require TableData::Object::aos;
+        TableData::Object::aos->new($data);
     } else {
         die "Unknown table data form, please supply array of scalar, ".
-            "array of array of scalar, or array of hash of scalar";
+            "array of array-of-scalar, or array of hash-of-scalar";
     }
 }
 
@@ -48,9 +52,34 @@ TableData::Object - Manipulate data structure via table object
 
 =head1 VERSION
 
-This document describes version 0.04 of TableData::Object (from Perl distribution TableData-Object), released on 2015-10-29.
+This document describes version 0.05 of TableData::Object (from Perl distribution TableData-Object), released on 2015-11-02.
 
-=for Pod::Coverage .+
+=for Pod::Coverage ^$
+
+=head1 FUNCTIONS
+
+=head2 table($data[ , $spec ]) => obj
+
+Shortcut for C<< TableData::Object->new(...) >>.
+
+=head1 METHODS
+
+=head2 new($data[ , $spec ]) => obj
+
+Detect the structure of C<$data> and create the appropriate
+C<TableData::Object::FORM> object.
+
+=head1 SEE ALSO
+
+L<TableData::Object::Base> for list of available methods.
+
+L<TableData::Object::aos>
+
+L<TableData::Object::aoaos>
+
+L<TableData::Object::aohos>
+
+L<TableData::Object::hash>
 
 =head1 HOMEPAGE
 
@@ -58,7 +87,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/TableData-
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-TableData-Object>.
+Source repository is at L<https://github.com/sharyanto/perl-TableData-Object>.
 
 =head1 BUGS
 
