@@ -1,7 +1,7 @@
 package TableData::Object::aoaos;
 
-our $DATE = '2015-10-29'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-11-02'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -43,28 +43,29 @@ sub row_count {
     scalar @{ $self->{data} };
 }
 
-sub sort_rows {
-    my ($self, @sortcols) = @_;
-    return $self unless @sortcols;
+sub rows_as_aoaos {
+    my $self = shift;
+    $self->{data};
+}
 
+sub rows_as_aohos {
+    my $self = shift;
     my $data = $self->{data};
 
-    my @aoaos = sort {
-        for my $sortcol (@sortcols) {
-            my ($reverse, $col) = $sortcol =~ /\A(-?)(.+)/;
-            my $idx = $self->col_idx($col);
-            die "Unknown sort column '$col'" unless defined($idx);
-            my $cmp = ($reverse ? -1:1) * ($a->[$idx] cmp $b->[$idx]);
-            return $cmp if $cmp;
+    my $cols = $self->{cols_by_idx};
+    my $rows = [];
+    for my $aos (@{$self->{data}}) {
+        my $row = {};
+        for my $i (0..$#{$cols}) {
+            $row->{$cols->[$i]} = $aos->[$i];
         }
-        0;
-    } @$data;
-
-    __PACKAGE__->new(\@aoaos, $self->{spec});
+        push @$rows, $row;
+    }
+    $rows;
 }
 
 1;
-# ABSTRACT: Manipulate array of scalars via table object
+# ABSTRACT: Manipulate array of arrays-of-scalars via table object
 
 __END__
 
@@ -74,21 +75,50 @@ __END__
 
 =head1 NAME
 
-TableData::Object::aoaos - Manipulate array of scalars via table object
+TableData::Object::aoaos - Manipulate array of arrays-of-scalars via table object
 
 =head1 VERSION
 
-This document describes version 0.04 of TableData::Object::aoaos (from Perl distribution TableData-Object), released on 2015-10-29.
+This document describes version 0.05 of TableData::Object::aoaos (from Perl distribution TableData-Object), released on 2015-11-02.
+
+=head1 SYNOPSIS
+
+To create:
+
+ use TableData::Object qw(table);
+
+ my $td = table([[1,2,3], [4,5,6]]);
+
+or:
+
+ use TableData::Object::aoaos;
+
+ my $td = TableData::Object::aoaos->new([[1,2,3], [4,5,6]]);
+
+To manipulate:
+
+ $td->cols_by_name; # {column0=>0, column1=>1, column2=>2}
+ $td->cols_by_idx;  # ['column0', 'column1', 'column2']
+
+=head1 DESCRIPTION
+
+This class lets you manipulate an array of arrays-of-scalars as a table object.
+The table will have column names C<column0>, C<column1>, and so on. The first
+array-of-scalars will determine the number of columns.
 
 =for Pod::Coverage .+
 
+=head1 METHODS
+
+See L<TableData::Object::Base>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/TableData-Object>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-TableData-Object>.
+Source repository is at L<https://github.com/sharyanto/perl-TableData-Object>.
 
 =head1 BUGS
 
