@@ -1,7 +1,7 @@
 package TableData::Object::aohos;
 
-our $DATE = '2015-10-29'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-11-02'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -47,29 +47,29 @@ sub row_count {
     scalar @{ $self->{data} };
 }
 
-sub sort_rows {
-    my ($self, @sortcols) = @_;
-    return $self unless @sortcols;
-
+sub rows_as_aoaos {
+    my $self = shift;
     my $data = $self->{data};
 
-    my @aohos = sort {
-        for my $sortcol (@sortcols) {
-            my ($reverse, $col) = $sortcol =~ /\A(-?)(.+)/;
-            my $name = $self->col_name($col);
-            die "Unknown sort column '$col'" unless defined($name);
-            my $cmp = ($reverse ? -1:1) *
-                (($a->{$name} // '') cmp ($b->{$name} // ''));
-            return $cmp if $cmp;
+    my $cols = $self->{cols_by_idx};
+    my $rows = [];
+    for my $hos (@{$self->{data}}) {
+        my $row = [];
+        for my $i (0..$#{$cols}) {
+            $row->[$i] = $hos->{$cols->[$i]};
         }
-        0;
-    } @$data;
+        push @$rows, $row;
+    }
+    $rows;
+}
 
-    __PACKAGE__->new(\@aohos, $self->{spec});
+sub rows_as_aohos {
+    my $self = shift;
+    $self->{data};
 }
 
 1;
-# ABSTRACT: Manipulate array of (hashes of scalars) via table object
+# ABSTRACT: Manipulate array of hashes-of-scalars via table object
 
 __END__
 
@@ -79,21 +79,49 @@ __END__
 
 =head1 NAME
 
-TableData::Object::aohos - Manipulate array of (hashes of scalars) via table object
+TableData::Object::aohos - Manipulate array of hashes-of-scalars via table object
 
 =head1 VERSION
 
-This document describes version 0.04 of TableData::Object::aohos (from Perl distribution TableData-Object), released on 2015-10-29.
+This document describes version 0.05 of TableData::Object::aohos (from Perl distribution TableData-Object), released on 2015-11-02.
+
+=head1 SYNOPSIS
+
+To create:
+
+ use TableData::Object qw(table);
+
+ my $td = table([{foo=>10, bar=>10}, {bar=>20, baz=>20}]);
+
+or:
+
+ use TableData::Object::aohos;
+
+ my $td = TableData::Object::aohos->new([{foo=>10, bar=>10}, {bar=>20, baz=>20}]);
+
+To manipulate:
+
+ $td->cols_by_name; # {foo=>0, bar=>1, baz=>2}
+ $td->cols_by_idx;  # ['foo', 'bar', 'baz']
+
+=head1 DESCRIPTION
+
+This class lets you manipulate an array of hashes-of-scalars as a table object.
+The table will have columns from all the hashes' keys.
 
 =for Pod::Coverage .+
 
+=head1 METHODS
+
+See L<TableData::Object::Base>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/TableData-Object>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-TableData-Object>.
+Source repository is at L<https://github.com/sharyanto/perl-TableData-Object>.
 
 =head1 BUGS
 
