@@ -1,7 +1,7 @@
 package TableData::Object::aos;
 
-our $DATE = '2015-10-29'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-11-02'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -23,24 +23,14 @@ sub row_count {
     scalar @{ $self->{data} };
 }
 
-sub sort_rows {
-    my ($self, @sortcols) = @_;
-    return $self unless @sortcols;
+sub rows_as_aoaos {
+    my $self = shift;
+    [map {[$_]} @{ $self->{data} }];
+}
 
-    my $data = $self->{data};
-
-    my @aos = sort {
-        for my $sortcol (@sortcols) {
-            my ($reverse, $col) = $sortcol =~ /\A(-?)(.+)/;
-            my $idx = $self->col_idx($col);
-            die "Unknown sort column '$col'" unless defined($idx);
-            my $cmp = ($reverse ? -1:1) * ($a cmp $b);
-            return $cmp if $cmp;
-        }
-        0;
-    } @$data;
-
-    __PACKAGE__->new(\@aos);
+sub rows_as_aohos {
+    my $self = shift;
+    [map {{elem=>$_}} @{ $self->{data} }];
 }
 
 1;
@@ -58,9 +48,37 @@ TableData::Object::aos - Manipulate array of scalars via table object
 
 =head1 VERSION
 
-This document describes version 0.04 of TableData::Object::aos (from Perl distribution TableData-Object), released on 2015-10-29.
+This document describes version 0.05 of TableData::Object::aos (from Perl distribution TableData-Object), released on 2015-11-02.
 
-=for Pod::Coverage .+
+=head1 SYNOPSIS
+
+To create:
+
+ use TableData::Object qw(table);
+
+ my $td = table([1,2,3]);
+
+or:
+
+ use TableData::Object::aos;
+
+ my $td = TableData::Object::aos->new([1,2,3]);
+
+To manipulate:
+
+ $td->cols_by_name; # {elem=>0}
+ $td->cols_by_idx;  # ['elem']
+
+=head1 DESCRIPTION
+
+This class lets you manipulate an array of scalars as a table object. The table
+will have a single column named C<elem>.
+
+=for Pod::Coverage .*
+
+=head1 METHODS
+
+See L<TableData::Object::Base>.
 
 =head1 HOMEPAGE
 
@@ -68,7 +86,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/TableData-
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-TableData-Object>.
+Source repository is at L<https://github.com/sharyanto/perl-TableData-Object>.
 
 =head1 BUGS
 
