@@ -1,7 +1,7 @@
 package TableData::Object::hash;
 
-our $DATE = '2015-10-29'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-11-02'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -24,37 +24,17 @@ sub row_count {
     scalar keys %{ $self->{data} };
 }
 
-sub sort_rows {
-    my ($self, @sortcols) = @_;
-    return $self unless @sortcols;
-
+sub rows_as_aoaos {
+    my $self = shift;
     my $data = $self->{data};
-
-    my @aoaos = sort {
-        for my $sortcol (@sortcols) {
-            say "D1";
-            my ($reverse, $col) = $sortcol =~ /\A(-?)(.+)/;
-            my $idx = $self->col_idx($col);
-            die "Unknown sort column '$col'" unless defined($idx);
-            my $cmp = ($reverse ? -1:1) * ($a->[$idx] cmp $b->[$idx]);
-            return $cmp if $cmp;
-        }
-        0;
-    } map {[$_, $data->{$_}]} keys %$data;
-
-    require TableData::Object::aoaos;
-    TableData::Object::aoaos->new(
-        data => \@aoaos,
-        spec => {
-            fields => {
-                key   => {pos=>0},
-                value => {pos=>1},
-            },
-            pk => 'key',
-        },
-    );
+    [map {[$_, $data->{$_}]} sort keys %$data];
 }
 
+sub rows_as_aohos {
+    my $self = shift;
+    my $data = $self->{data};
+    [map {{key=>$_, value=>$data->{$_}}} sort keys %$data];
+}
 
 1;
 # ABSTRACT: Manipulate hash via table object
@@ -71,17 +51,46 @@ TableData::Object::hash - Manipulate hash via table object
 
 =head1 VERSION
 
-This document describes version 0.04 of TableData::Object::hash (from Perl distribution TableData-Object), released on 2015-10-29.
+This document describes version 0.05 of TableData::Object::hash (from Perl distribution TableData-Object), released on 2015-11-02.
+
+=head1 SYNOPSIS
+
+To create:
+
+ use TableData::Object qw(table);
+
+ my $td = table({foo=>10, bar=>20, baz=>30});
+
+or:
+
+ use TableData::Object::hash;
+
+ my $td = TableData::Object::hash->new({foo=>10, bar=>20, baz=>30});
+
+To manipulate:
+
+ $td->cols_by_name; # {key=>0, value=>1}
+ $td->cols_by_idx;  # ['key', 'value']
+
+=head1 DESCRIPTION
+
+This class lets you manipulate a hash as a table object. The table will have two
+columns named C<key> (containing hash keys) and C<value> (containing hash
+values).
 
 =for Pod::Coverage .+
 
+=head1 METHODS
+
+See L<TableData::Object::Base>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/TableData-Object>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-TableData-Object>.
+Source repository is at L<https://github.com/sharyanto/perl-TableData-Object>.
 
 =head1 BUGS
 
